@@ -42,7 +42,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.10.1'; # VERSION
+our $VERSION = 'v0.10.2'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -368,12 +368,12 @@ sub configure {
                     our $cpan_rt_mailto = "mailto:bug-$name\@rt.cpan.org";
                     our $cpan_rt_browse = "https://rt.cpan.org/Public/Dist/Display.html?Name=$name";
                     our $cpan_rt_report = "https://rt.cpan.org/Public/Bug/Report.html?Queue=$name";
-                    our $repo_type      = "hg";
-                    our $repo_host      = "fedorapeople.org";
-                    our $repo_url       = "https://vandebugger.$repo_host/hg/perl-$name";
-                    our $repo_web       = undef;
+                    our $repo_type      ||= "hg";
+                    our $repo_host      ||= "fedorapeople.org";
+                    our $repo_url       ||= "https://vandebugger.$repo_host/hg/perl-$name";
+                    our $repo_web       ||= undef;
                     our $repo_clone     = "$repo_type clone $repo_url" .
-                        ( $repo_url =~ m{/\Qperl-$name\E\z} ? '' : " \\\n        perl-$name" );
+                        ( $repo_url =~ m{/\Qperl-$name\E\z} ? '' : " \\\\\\n        perl-$name" );
                     our $bundle         = $Dist::Zilla::PluginBundle::Author::VDB::Self;
                 };
                 $ENV{ 'TEST_FIX' . 'ME_FORMAT' } = 'perl';      # Hide keyword from `fixme.t`.
@@ -980,7 +980,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.10.1, released on 2015-10-22 15:21 UTC.
+Version v0.10.2, released on 2015-10-22 21:30 UTC.
 
 =head1 WHAT?
 
